@@ -17,7 +17,9 @@ class InvalidAuthority(RFC3986Exception):
         """Initialize the exception with the invalid authority."""
         super(InvalidAuthority, self).__init__(
             u"The authority ({0}) is not valid.".format(
-                compat.to_str(authority)))
+                compat.to_str(authority)
+            )
+        )
 
 
 class InvalidPort(RFC3986Exception):
@@ -26,7 +28,8 @@ class InvalidPort(RFC3986Exception):
     def __init__(self, port):
         """Initialize the exception with the invalid port."""
         super(InvalidPort, self).__init__(
-            'The port ("{0}") is not valid.'.format(port))
+            'The port ("{0}") is not valid.'.format(port)
+        )
 
 
 class ResolutionError(RFC3986Exception):
@@ -35,7 +38,8 @@ class ResolutionError(RFC3986Exception):
     def __init__(self, uri):
         """Initialize the error with the failed URI."""
         super(ResolutionError, self).__init__(
-            "{0} is not an absolute URI.".format(uri.unsplit()))
+            "{0} is not an absolute URI.".format(uri.unsplit())
+        )
 
 
 class ValidationError(RFC3986Exception):
@@ -49,13 +53,13 @@ class MissingComponentError(ValidationError):
 
     def __init__(self, uri, *component_names):
         """Initialize the error with the missing component name."""
-        verb = 'was'
+        verb = "was"
         if len(component_names) > 1:
-            verb = 'were'
+            verb = "were"
 
         self.uri = uri
         self.components = sorted(component_names)
-        components = ', '.join(self.components)
+        components = ", ".join(self.components)
         super(MissingComponentError, self).__init__(
             "{} {} required but missing".format(components, verb),
             uri,
@@ -70,7 +74,9 @@ class UnpermittedComponentError(ValidationError):
         """Initialize the error with the unpermitted component."""
         super(UnpermittedComponentError, self).__init__(
             "{} was required to be one of {!r} but was {!r}".format(
-                component_name, list(sorted(allowed_values)), component_value,
+                component_name,
+                list(sorted(allowed_values)),
+                component_value,
             ),
             component_name,
             component_value,
@@ -86,7 +92,7 @@ class PasswordForbidden(ValidationError):
 
     def __init__(self, uri):
         """Initialize the error with the URI that failed validation."""
-        unsplit = getattr(uri, 'unsplit', lambda: uri)
+        unsplit = getattr(uri, "unsplit", lambda: uri)
         super(PasswordForbidden, self).__init__(
             '"{}" contained a password when validation forbade it'.format(
                 unsplit()
@@ -100,13 +106,13 @@ class InvalidComponentsError(ValidationError):
 
     def __init__(self, uri, *component_names):
         """Initialize the error with the invalid component name(s)."""
-        verb = 'was'
+        verb = "was"
         if len(component_names) > 1:
-            verb = 'were'
+            verb = "were"
 
         self.uri = uri
         self.components = sorted(component_names)
-        components = ', '.join(self.components)
+        components = ", ".join(self.components)
         super(InvalidComponentsError, self).__init__(
             "{} {} found to be invalid".format(components, verb),
             uri,
